@@ -46,23 +46,20 @@
 #'            exposure = exposure, by = list(bm, power))
 #'
 #' @export
-univariate <- function (df, x, severity = NULL, nclaims = NULL, exposure = NULL,
-                   premium = NULL, by = NULL) {
+univariate <- function(df, x, severity = NULL, nclaims = NULL, exposure = NULL,
+                       premium = NULL, by = NULL) {
 
   nse_se_input <- function(x) {
     expr <- substitute(x)
     if (is.call(expr) && expr[[1]] == quote(vec_ext)) {
       as.character(eval.parent(expr[[2]]))
-    }
-    else if (is.character(expr)) {
+    } else if (is.character(expr)) {
       x
-    }
-    else if (is.call(expr) && (expr[[1]] == quote(list) ||
-                               expr[[1]] == quote(c) ||
-                               expr[[1]] == quote(.))) {
+    } else if (is.call(expr) && (expr[[1]] == quote(list) ||
+                                 expr[[1]] == quote(c) ||
+                                 expr[[1]] == quote(.))) {
       as.character(expr[-1L])
-    }
-    else {
+    } else {
       deparse(expr)
     }
   }
@@ -80,61 +77,62 @@ univariate <- function (df, x, severity = NULL, nclaims = NULL, exposure = NULL,
     stop("Column(s) ", .xvar, " can't be found in data.frame", call. = FALSE)
   }
 
-  if ( length(.xvar) >  1 ){
+  if (length(.xvar) >  1) {
     .by <- append(.xvar[-1], .by)
     .xvar <- .xvar[1]
   }
 
-  COLS <- c()
-  if (!missing(severity)) { COLS <- append(COLS, .severity) }
-  if (!missing(nclaims)) { COLS <- append(COLS, .nclaims) }
-  if (!missing(exposure)) { COLS <- append(COLS, .exposure) }
-  if (!missing(premium)) { COLS <- append(COLS, .premium) }
+  cols_ <- c()
+  if (!missing(severity)) cols_ <- append(cols_, .severity)
+  if (!missing(nclaims)) cols_ <- append(cols_, .nclaims)
+  if (!missing(exposure)) cols_ <- append(cols_, .exposure)
+  if (!missing(premium)) cols_ <- append(cols_, .premium)
 
-  if (length(COLS) == 0) {
+  if (length(cols_) == 0) {
     stop("Define column names.", call. = FALSE)
   }
 
   BY <- setdiff(append(.xvar, .by), "NULL")
   dt <- data.table::data.table(df)[, lapply(.SD, sum, na.rm = TRUE),
-                                   by = BY, .SDcols = COLS]
+                                   by = BY, .SDcols = cols_]
 
   dt1 <- NULL
   if (!missing(by)) {
     dt1 <- data.table::data.table(df)[, lapply(.SD, sum, na.rm = TRUE),
-                                      by = .xvar, .SDcols = COLS]
+                                      by = .xvar, .SDcols = cols_]
   }
 
-  frequency = average_severity = risk_premium = loss_ratio = average_premium = NULL
+  frequency <- average_severity <- risk_premium <- loss_ratio <-
+    average_premium <- NULL
 
-  if (all(c(.nclaims, .exposure) %in% COLS)) {
+  if (all(c(.nclaims, .exposure) %in% cols_)) {
     dt <- dt[, `:=`(frequency, get(.nclaims) / get(.exposure))]
     if (!missing(by)) {
       dt1 <- dt1[, `:=`(frequency, get(.nclaims) / get(.exposure))]
     }
   }
-  if (all(c(.severity, .nclaims) %in% COLS)) {
+  if (all(c(.severity, .nclaims) %in% cols_)) {
     dt <- dt[, `:=`(average_severity, get(.severity) / get(.nclaims))]
     if (!missing(by)) {
       dt1 <- dt1[, `:=`(average_severity, get(.severity) / get(.nclaims))]
     }
   }
-  if (all(c(.severity, .exposure) %in% COLS)) {
+  if (all(c(.severity, .exposure) %in% cols_)) {
     dt <- dt[, `:=`(risk_premium, get(.severity) / get(.exposure))]
     if (!missing(by)) {
       dt1 <- dt1[, `:=`(risk_premium, get(.severity) / get(.exposure))]
     }
   }
-  if (all(c(.severity, .premium) %in% COLS)) {
+  if (all(c(.severity, .premium) %in% cols_)) {
     dt <- dt[, `:=`(loss_ratio, get(.severity) / get(.premium))]
     if (!missing(by)) {
       dt1 <- dt1[, `:=`(loss_ratio, get(.severity) / get(.premium))]
     }
   }
-  if (all(c(.premium, .exposure) %in% COLS)) {
-    dt <- dt[, `:=`(average_premium, get(.premium)/get(.exposure))]
+  if (all(c(.premium, .exposure) %in% cols_)) {
+    dt <- dt[, `:=`(average_premium, get(.premium) / get(.exposure))]
     if (!missing(by)) {
-      dt1 <- dt1[, `:=`(average_premium, get(.premium)/get(.exposure))]
+      dt1 <- dt1[, `:=`(average_premium, get(.premium) / get(.exposure))]
     }
   }
 
@@ -218,7 +216,7 @@ autoplot.univariate <- function(object, show_plots = 1:9, ncol = 1,
                                 color_bg = "lightskyblue", label_width = 10,
                                 coord_flip = FALSE, show_total = FALSE,
                                 total_color = NULL, total_name = NULL,
-                                rotate_angle = NULL, ...){
+                                rotate_angle = NULL, ...) {
 
   xvar <- attr(object, "xvar")
   nclaims <- attr(object, "nclaims")
@@ -227,33 +225,35 @@ autoplot.univariate <- function(object, show_plots = 1:9, ncol = 1,
   premium <- attr(object, "premium")
   by <- as.character(attr(object, "by"))
 
-  if ( length(xvar) > 1 ){
+  if (length(xvar) > 1) {
     message(xvar, "has more than one element. Only the first is shown.")
     xvar <- xvar[1]
   }
 
-  if ( length(by) == 0 ) { by <- "NULL" }
+  if (length(by) == 0) {
+    by <- "NULL"
+  }
 
   dfby0 <- attr(object, "dfby")
 
-  if ( length(by) > 1){
+  if (length(by) > 1) {
     stop("length of `by` in `univariate()` must be equal to one", call. = FALSE)
   }
 
-  if ( !is.numeric(show_plots) ){
+  if (!is.numeric(show_plots)) {
     stop("`show_plots` should be numeric", call. = FALSE)
   }
 
-  if ( !any(show_plots > 0 & show_plots < 10) ){
+  if (min(show_plots) < 1 || max(show_plots) > 9) {
     stop("elements in `show_plots` are unknown", call. = FALSE)
   }
 
-  if ( length(show_plots) > 1 & isTRUE(coord_flip) ){
+  if (length(show_plots) > 1 && isTRUE(coord_flip)) {
     stop("length of `show_plots` must be equal to one in
          case `coord_flip = TRUE`", call. = FALSE)
   }
 
-  if ( by == "NULL" ){
+  if (by == "NULL") {
     df <- object
     dfby <- dfby0
   } else {
@@ -261,27 +261,27 @@ autoplot.univariate <- function(object, show_plots = 1:9, ncol = 1,
     dfby <- object
   }
 
-  if ( !is.factor(df[[xvar]]) ){
+  if (!is.factor(df[[xvar]])) {
     df[[xvar]] <- as.factor(df[[xvar]])
     dfby[[xvar]] <- as.factor(dfby[[xvar]])
     dfby[[by]] <- as.factor(dfby[[by]])
   }
 
-  if ( by != "NULL" ){
-    if ( !is.factor(dfby[[xvar]]) ){
+  if (by != "NULL") {
+    if (!is.factor(dfby[[xvar]])) {
       dfby[[xvar]] <- as.factor(dfby[[xvar]])
     }
 
-    if ( !is.factor(dfby[[by]]) ){
+    if (!is.factor(dfby[[by]])) {
       dfby[[by]] <- as.factor(dfby[[by]])
     }
   }
 
-  if ( is.null(total_color) ){
+  if (is.null(total_color)) {
     total_color <- "black"
   }
 
-  if ( isTRUE(sort) & exposure != "NULL" ){
+  if (isTRUE(sort) && exposure != "NULL") {
     df[[xvar]] <- order_factors_exposure(df[[xvar]], df[[exposure]],
                                          decreasing = coord_flip)
   }
@@ -291,123 +291,136 @@ autoplot.univariate <- function(object, show_plots = 1:9, ncol = 1,
   plots_allowed <- show_plots[show_plots < 10 & show_plots > 0]
   not_allowed <- NULL
 
-  if ( "frequency" %in% names(df) & 1 %in% show_plots ){
+  if ("frequency" %in% names(df) && 1 %in% show_plots) {
     p1 <- ggbarline(background, df, dfby, xvar,
                     "frequency", "Frequency", exposure,
                     color_bg, color, sep_mark, by, labels,
                     sort_manual, label_width,
                     show_total, total_color, total_name)
-  } else( not_allowed <- c(not_allowed, 1) )
+  } else {
+    (not_allowed <- c(not_allowed, 1))
+  }
 
-  if ( "average_severity" %in% names(df) & 2 %in% show_plots ){
+  if ("average_severity" %in% names(df) && 2 %in% show_plots) {
     p2 <- ggbarline(background, df, dfby, xvar,
                     "average_severity", "Average\nseverity", nclaims,
                     color_bg, color, sep_mark, by, labels,
                     sort_manual, label_width,
                     show_total, total_color, total_name)
-    if ( !1 %in% not_allowed ) { p2 <- p2 + theme(legend.position = "none") }
-  } else( not_allowed <- c(not_allowed, 2) )
+    if (!1 %in% not_allowed) p2 <- p2 + theme(legend.position = "none")
+  } else {
+    (not_allowed <- c(not_allowed, 2))
+  }
 
-  if ( "risk_premium" %in% names(df) & 3 %in% show_plots ){
+  if ("risk_premium" %in% names(df) && 3 %in% show_plots) {
     p3 <- ggbarline(background, df, dfby, xvar,
                     "risk_premium", "Risk premium", exposure,
                     color_bg, color, sep_mark, by, labels,
                     sort_manual, label_width,
                     show_total, total_color, total_name)
-    if ( !all(1:2 %in% not_allowed) ) { p3 <- p3 +
-      theme(legend.position = "none") }
-  } else( not_allowed <- c(not_allowed, 3) )
+    if (!all(1:2 %in% not_allowed)) p3 <- p3 + theme(legend.position = "none")
+  } else {
+    (not_allowed <- c(not_allowed, 3))
+  }
 
-  if ( "loss_ratio" %in% names(df) & 4 %in% show_plots ){
+  if ("loss_ratio" %in% names(df) && 4 %in% show_plots) {
     p4 <- ggbarline(background, df, dfby, xvar,
                     "loss_ratio", "Loss ratio", premium,
                     color_bg, color, sep_mark, by, labels,
                     sort_manual, label_width,
                     show_total, total_color, total_name)
-    if ( !all(1:3 %in% not_allowed) ) { p4 <- p4 +
-      theme(legend.position = "none") }
-  } else( not_allowed <- c(not_allowed, 4) )
+    if (!all(1:3 %in% not_allowed)) p4 <- p4 + theme(legend.position = "none")
+  } else {
+    (not_allowed <- c(not_allowed, 4))
+  }
 
-  if ( "average_premium" %in% names(df) & 5 %in% show_plots ){
+  if ("average_premium" %in% names(df) && 5 %in% show_plots) {
     p5 <- ggbarline(background, df, dfby, xvar,
                     "average_premium", "Average\npremium", exposure,
                     color_bg, color, sep_mark, by, labels,
                     sort_manual, label_width,
                     show_total, total_color, total_name)
-    if ( !all(1:4 %in% not_allowed) ) { p5 <- p5 +
-      theme(legend.position = "none") }
-  } else( not_allowed <- c(not_allowed, 5) )
+    if (!all(1:4 %in% not_allowed)) p5 <- p5 + theme(legend.position = "none")
+  } else {
+    (not_allowed <- c(not_allowed, 5))
+  }
 
-  if ( exposure %in% names(df) & 6 %in% show_plots ){
+  if (exposure %in% names(df) && 6 %in% show_plots) {
     p6 <- ggbar(df, xvar, exposure, color_bg, sep_mark, coord_flip)
-  } else( not_allowed <- c(not_allowed, 6))
+  } else {
+    (not_allowed <- c(not_allowed, 6))
+  }
 
-  if ( severity %in% names(df) & 7 %in% show_plots ){
+  if (severity %in% names(df) && 7 %in% show_plots) {
     p7 <- ggbar(df, xvar, severity, color_bg, sep_mark, coord_flip)
-  } else( not_allowed <- c(not_allowed, 7))
+  } else {
+    (not_allowed <- c(not_allowed, 7))
+  }
 
-  if ( nclaims %in% names(df) & 8 %in% show_plots ){
+  if (nclaims %in% names(df) && 8 %in% show_plots) {
     p8 <- ggbar(df, xvar, nclaims, color_bg, sep_mark, coord_flip)
-  } else( not_allowed <- c(not_allowed, 8))
+  } else {
+    (not_allowed <- c(not_allowed, 8))
+  }
 
-  if ( premium %in% names(df) & 9 %in% show_plots ){
+  if (premium %in% names(df) && 9 %in% show_plots) {
     p9 <- ggbar(df, xvar, premium, color_bg, sep_mark, coord_flip)
-  } else( not_allowed <- c(not_allowed, 9))
+  } else {
+    (not_allowed <- c(not_allowed, 9))
+  }
 
   plots_possible <- setdiff(plots_allowed, not_allowed)
 
-  if ( length (plots_possible) == 0 ){
+  if (length(plots_possible) == 0) {
     stop("Ignoring plots: input is unknown", call. = FALSE)
   }
 
   diff_plots <- setdiff(show_plots, plots_possible)
-  if ( length (diff_plots) > 0 ){
+  if (length(diff_plots) > 0) {
     message(paste0("Ignoring plots ",
                    paste0(diff_plots, collapse = ", "), ": input is unknown"))
   }
 
-  if ( isTRUE(sort) & exposure == "NULL" ){
+  if (isTRUE(sort) && exposure == "NULL") {
     message("Ignoring sort: exposure is unknown")
   }
 
-  if ( isTRUE(coord_flip) & length(plots_possible) > 1 ) {
+  if (isTRUE(coord_flip) && length(plots_possible) > 1) {
     message("`coord_flip` only works for one bar graph")
   }
 
-  if ( ncol == 1 ){
-    remove_axis <- list( theme(axis.title.x = element_blank(),
-                               axis.text.x = element_blank(),
-                               axis.ticks.x = element_blank()) )
+  if (ncol == 1) {
+    remove_axis <- list(theme(axis.title.x = element_blank(),
+                              axis.text.x = element_blank(),
+                              axis.ticks.x = element_blank()))
 
     plot_last <- paste0("p",
-                        plots_possible[length( plots_possible )],
+                        plots_possible[length(plots_possible)],
                         collapse = " + ")
 
-    if ( length(plots_possible) == 1 ){
-      plot_out <- eval(parse( text = plot_last ))
+    if (length(plots_possible) == 1) {
+      plot_out <- eval(parse(text = plot_last))
     }
 
-    if ( length(plots_possible) > 1 ){
+    if (length(plots_possible) > 1) {
       plot_nrs <- paste0("p", plots_possible[-length(plots_possible)],
                          " + remove_axis", collapse = " + ")
       plot_all <- paste0("(", plot_nrs, " + ", plot_last, ")")
-      plot_out <- eval(parse( text = plot_all )) +
-        patchwork::plot_layout(ncol = 1, guides = 'collect')
+      plot_out <- eval(parse(text = plot_all)) +
+        patchwork::plot_layout(ncol = 1, guides = "collect")
     }
   } else {
     plot_all <- paste0("p", plots_possible, collapse = " + ")
-    plot_out <- eval(parse( text = plot_all )) +
-      patchwork::plot_layout(ncol = ncol, guides = 'collect')
+    plot_out <- eval(parse(text = plot_all)) +
+      patchwork::plot_layout(ncol = ncol, guides = "collect")
   }
 
-  if ( !is.null(rotate_angle) ){
+  if (!is.null(rotate_angle)) {
     plot_out <- plot_out +
       ggplot2::theme(axis.text.x = element_text(angle = rotate_angle,
                                                 vjust = 0.5,
                                                 hjust = 1))
   }
 
-  return(plot_out)
+  plot_out
 }
-
-
