@@ -28,11 +28,11 @@
 #'
 #' @export
 biggest_reference <- function(x, weight) {
-  if(!is.numeric(weight)) weight <- is.numeric(weight)
+  if (!is.numeric(weight)) weight <- is.numeric(weight)
   counts <- sort(tapply(weight, x, FUN = sum), decreasing = TRUE)
   xrelevel <- stats::relevel(x, ref = names(counts)[1])
   attr(xrelevel, "xoriginal") <- levels(x)
-  return(xrelevel)
+  xrelevel
 }
 
 
@@ -63,51 +63,51 @@ biggest_reference <- function(x, weight) {
 #' doi: 10.1080/01621459.1958.10501479.
 #'
 #' @export fisher
-fisher <- function(vec, n = 7, diglab = 2){
-  cluster <- classInt::classIntervals(vec, n = n, style = 'fisher',
-                                      intervalClosure = 'right')[[2]]
+fisher <- function(vec, n = 7, diglab = 2) {
+  cluster <- classInt::classIntervals(vec, n = n, style = "fisher",
+                                      intervalClosure = "right")[[2]]
   cut(vec, breaks = cluster, include.lowest = TRUE, dig.lab = diglab)
 }
 
 
 #' @keywords internal
-make_stars <- function(pval){
+make_stars <- function(pval) {
   # returns character string
-  if (is.na(pval)) { pval <- is.numeric(pval) }
-  if (pval > 0 & pval <= 0.001)
-    stars = "***"
-  else if (pval > 0.001 & pval <= 0.01)
-    stars = "**"
-  else if (pval > 0.01 & pval <= 0.05)
-    stars = "*"
-  else if (pval > 0.05 & pval <= 0.1)
-    stars = "."
-  else {
-    stars = ""
+  if (is.na(pval)) {
+    pval <- is.numeric(pval)
+  }
+  if (pval > 0 && pval <= 0.001) {
+    stars <- "***"
+  } else if (pval > 0.001 && pval <= 0.01) {
+    stars <- "**"
+  } else if (pval > 0.01 && pval <= 0.05) {
+    stars <- "*"
+  } else if (pval > 0.05 && pval <= 0.1) {
+    stars <- "."
+  } else {
+    stars <- ""
   }
   stars
 }
 
 
 #' @keywords internal
-elapsed_days <- function(end_date){
+elapsed_days <- function(end_date) {
   as.POSIXlt(end_date)$mday - 1
 }
 
 #' @keywords internal
 matchColClasses <- function(df1, df2) {
 
-  sharedColNames <- names(df1)[names(df1) %in% names(df2)]
-  #sharedColTypes <- vapply(df1[, sharedColNames, drop = FALSE], class,
-  #                         FUN.VALUE = character(1))
-  sharedColTypes <- sapply(df1[,sharedColNames, drop = FALSE], class)
+  shared_colnames <- names(df1)[names(df1) %in% names(df2)]
+  shared_coltypes <- sapply(df1[, shared_colnames, drop = FALSE], class)
 
-  for (n in sharedColNames) {
-    attributes(df2[,n]) <- attributes(df1[,n])
-    class(df2[, n]) <- sharedColTypes[n]
+  for (n in shared_colnames) {
+    attributes(df2[, n]) <- attributes(df1[, n])
+    class(df2[, n]) <- shared_coltypes[n]
   }
 
-  return(df2)
+  df2
 }
 
 
@@ -148,16 +148,16 @@ order_factors_exposure <- function(x, weight, decreasing) {
 
 
 #' @keywords internal
-scale_second_axis <- function(background, df, dfby, f_axis, s_axis, by){
-  if ( isTRUE(background) ){
+scale_second_axis <- function(background, df, dfby, f_axis, s_axis, by) {
+  if (isTRUE(background)) {
 
-    if ( by == "NULL"){
+    if (by == "NULL") {
       df$s_axis_scale <- df[[s_axis]] / max(df[[s_axis]], na.rm = TRUE) *
         max(df[[f_axis]], na.rm = TRUE)
       df$s_axis_print <- round(df[[s_axis]], 0)
     }
 
-    if ( by != "NULL"){
+    if (by != "NULL") {
       df$s_axis_scale <- df[[s_axis]] / max(df[[s_axis]], na.rm = TRUE) *
         max(dfby[[f_axis]], na.rm = TRUE)
       df$s_axis_print <- round(df[[s_axis]], 0)
@@ -169,38 +169,43 @@ scale_second_axis <- function(background, df, dfby, f_axis, s_axis, by){
 
 
 #' @keywords internal
-separation_mark <- function(dec.mark){
-  if ( dec.mark == "," ){
-    function(x) format(x, big.mark = ".", decimal.mark = ",",
-                       scientific = FALSE)
-  } else{
-    function(x) format(x, big.mark = ",", decimal.mark = ".",
-                       scientific = FALSE)
+separation_mark <- function(dec.mark) {
+  if (dec.mark == ",") {
+    function(x) {
+      format(x, big.mark = ".", decimal.mark = ",", scientific = FALSE)
+    }
+  } else {
+    function(x) {
+      format(x, big.mark = ",", decimal.mark = ".", scientific = FALSE)
+    }
   }
 }
 
 
 #' @keywords internal
-sort_x_axis <- function(sort_manual, label_width){ # hist_sort
-  if ( !is.null(sort_manual) ){
+sort_x_axis <- function(sort_manual, label_width) { # hist_sort
+  if (!is.null(sort_manual)) {
     list(
-      ggplot2::scale_x_discrete(labels = function(x)
-        stringr::str_wrap(x, width = label_width), limits = sort_manual )
+      ggplot2::scale_x_discrete(
+        labels = function(x) stringr::str_wrap(x, width = label_width),
+        limits = sort_manual
+      )
     )
-  } else{
+  } else {
     list(
-      ggplot2::scale_x_discrete(labels = function(x)
-        stringr::str_wrap(x, width = label_width) )
+      ggplot2::scale_x_discrete(
+        labels = function(x) stringr::str_wrap(x, width = label_width)
+      )
     )
   }
 }
 
 #' @importFrom colorspace lighten
 #' @keywords internal
-lighten_color <- function(color, amount = 0.25, n = 3){
+lighten_color <- function(color, amount = 0.25, n = 3) {
   x <- vector(mode = "character", length = n)
   x[1] <- color
-  if (n > 1){
+  if (n > 1) {
     for (i in 2:n){
       x[i] <- colorspace::lighten(color, i * amount)
     }
@@ -210,10 +215,10 @@ lighten_color <- function(color, amount = 0.25, n = 3){
 
 #' @importFrom colorspace darken
 #' @keywords internal
-darken_color <- function(color, amount = 0.25, n = 3){
+darken_color <- function(color, amount = 0.25, n = 3) {
   x <- vector(mode = "character", length = n)
   x[1] <- color
-  if (n > 1){
+  if (n > 1) {
     for (i in 2:n){
       x[i] <- colorspace::darken(color, i * amount)
     }
@@ -225,28 +230,28 @@ darken_color <- function(color, amount = 0.25, n = 3){
 
 #' @keywords internal
 ggbarplot <- function(background, df, dfby, xvar, f_axis, s_axis, color_bg,
-                      sep_mark, by){
+                      sep_mark, by) {
   fill_bg <- lighten_color(color_bg)[2]
-  if ( isTRUE(background) & by == "NULL" ){
+  if (isTRUE(background) && by == "NULL") {
 
-      list(
-        ggplot2::geom_bar(data = df, aes(x = .data[[xvar]],
-                                         y = .data[["s_axis_scale"]]),
-                          stat = "identity", color = color_bg,
-                          fill = fill_bg, alpha = 1),
-        ggplot2::scale_y_continuous(sec.axis = sec_axis(~ . *
-                                                          max(df[[s_axis]]) /
-                                                          max(df[[f_axis]]),
-                                                        name = s_axis,
-                                                        labels = sep_mark),
-                                    labels = sep_mark,
-                                    limits = c(0, NA),
-                                    expand = expansion(mult = c(0, 0.01))
-        )
+    list(
+      ggplot2::geom_bar(data = df, aes(x = .data[[xvar]],
+                                       y = .data[["s_axis_scale"]]),
+                        stat = "identity", color = color_bg,
+                        fill = fill_bg, alpha = 1),
+      ggplot2::scale_y_continuous(sec.axis = sec_axis(~ . *
+                                                        max(df[[s_axis]],
+                                                            na.rm = TRUE) /
+                                                        max(df[[f_axis]],
+                                                            na.rm = TRUE),
+                                                      name = s_axis,
+                                                      labels = sep_mark),
+                                  labels = sep_mark,
+                                  limits = c(0, NA),
+                                  expand = expansion(mult = c(0, 0.01))
       )
-  }
-
-  else if ( isTRUE(background) & by != "NULL" ){
+    )
+  } else if (isTRUE(background) && by != "NULL") {
 
     list(
       ggplot2::geom_bar(data = df, aes(x = .data[[xvar]],
@@ -265,16 +270,16 @@ ggbarplot <- function(background, df, dfby, xvar, f_axis, s_axis, color_bg,
                                   expand = expansion(mult = c(0, 0.01))
       )
     )
+  } else {
+    NULL
   }
-
-  else{ NULL }
 }
 
 
 #' @keywords internal
 ggpointline <- function(df, dfby, xvar, y, color, by,
-                        show_total, total_color, total_name){
-  if ( by == "NULL"){
+                        show_total, total_color, total_name) {
+  if (by == "NULL") {
     list(
       ggplot2::geom_point(data = df,
                           aes(x = .data[[xvar]],
@@ -288,31 +293,31 @@ ggpointline <- function(df, dfby, xvar, y, color, by,
       ggplot2::theme_minimal()
     )
   } else {
-    if ( isTRUE(show_total) ){
-    list(
-      ggplot2::geom_point(data = dfby,
-                          aes(x = .data[[xvar]],
-                              y = .data[[y]],
-                              color = .data[[by]])),
-      ggplot2::geom_line(data = dfby,
-                         aes(x = .data[[xvar]],
-                             y = .data[[y]],
-                             group = .data[[by]],
-                             color = as.factor(.data[[by]]))),
-      ggplot2::theme_minimal(),
-      ggplot2::labs(color = by, linetype = NULL),
-      ggplot2::geom_point(data = df,
-                          aes(x = .data[[xvar]],
-                              y = .data[[y]]),
-                          color = total_color),
-      ggplot2::geom_line(data = df,
-                         aes(x = .data[[xvar]],
-                             y = .data[[y]],
-                             linetype = total_name,
-                             group = "black"),
-                         color = total_color)
-    )}
-    else {
+    if (isTRUE(show_total)) {
+      list(
+        ggplot2::geom_point(data = dfby,
+                            aes(x = .data[[xvar]],
+                                y = .data[[y]],
+                                color = .data[[by]])),
+        ggplot2::geom_line(data = dfby,
+                           aes(x = .data[[xvar]],
+                               y = .data[[y]],
+                               group = .data[[by]],
+                               color = as.factor(.data[[by]]))),
+        ggplot2::theme_minimal(),
+        ggplot2::labs(color = by, linetype = NULL),
+        ggplot2::geom_point(data = df,
+                            aes(x = .data[[xvar]],
+                                y = .data[[y]]),
+                            color = total_color),
+        ggplot2::geom_line(data = df,
+                           aes(x = .data[[xvar]],
+                               y = .data[[y]],
+                               linetype = total_name,
+                               group = "black"),
+                           color = total_color)
+      )
+    } else {
       list(
         ggplot2::geom_point(data = dfby,
                             aes(x = .data[[xvar]],
@@ -332,8 +337,8 @@ ggpointline <- function(df, dfby, xvar, y, color, by,
 
 
 #' @keywords internal
-gglabels <- function(background, labels, df, xvar, sep_mark){
-  if ( isTRUE(background) & isTRUE(labels) ){
+gglabels <- function(background, labels, df, xvar, sep_mark) {
+  if (isTRUE(background) && isTRUE(labels)) {
     list(
       ggplot2::geom_text(data = df,
                          aes(x = .data[[xvar]],
@@ -342,16 +347,18 @@ gglabels <- function(background, labels, df, xvar, sep_mark){
                          vjust = "inward",
                          size = 3)
     )
-  } else { NULL }
+  } else {
+    NULL
+  }
 }
 
 
 #' @keywords internal
-ggbarlabels <- function(df, xvar, y, coord_flip, sep_mark){
+ggbarlabels <- function(df, xvar, y, coord_flip, sep_mark) {
 
   df$y_print <- round(df[[y]], 0)
 
-  if ( isTRUE(coord_flip) ){
+  if (isTRUE(coord_flip)) {
     list(
       ggplot2::geom_text(data = df,
                          aes(x = .data[[xvar]],
@@ -360,9 +367,7 @@ ggbarlabels <- function(df, xvar, y, coord_flip, sep_mark){
                          hjust = "inward",
                          size = 3)
     )
-  }
-
-  else if ( !isTRUE(coord_flip) ) {
+  } else if (!isTRUE(coord_flip)) {
     list(
       ggplot2::geom_text(data = df,
                          aes(x = .data[[xvar]],
@@ -376,8 +381,8 @@ ggbarlabels <- function(df, xvar, y, coord_flip, sep_mark){
 
 
 #' @keywords internal
-ggyscale <- function(background, sep_mark){
-  if ( !isTRUE( background )){
+ggyscale <- function(background, sep_mark) {
+  if (!isTRUE(background)) {
     list(
       ggplot2::scale_y_continuous(labels = sep_mark)
     )
@@ -389,7 +394,7 @@ ggyscale <- function(background, sep_mark){
 ggbarline <- function(background, df, dfby, xvar, f_axis,
                       f_axis_name, exposure, color_bg, color,
                       sep_mark, by, labels, sort_manual, label_width,
-                      show_total, total_color, total_name){
+                      show_total, total_color, total_name) {
   df <- scale_second_axis(background, df, dfby, f_axis, exposure, by)
   ggplot2::ggplot() +
     ggbarplot(background, df, dfby, xvar, f_axis, exposure,
@@ -404,7 +409,7 @@ ggbarline <- function(background, df, dfby, xvar, f_axis,
 
 
 #' @keywords internal
-ggbar <- function(df, xvar, f_axis, color_bg, sep_mark, coord_flip){
+ggbar <- function(df, xvar, f_axis, color_bg, sep_mark, coord_flip) {
   fill_bg <- lighten_color(color_bg)[2]
   ggplot2::ggplot(data = df) +
     ggplot2::geom_bar(data = df, aes(x = .data[[xvar]], y = .data[[f_axis]]),
@@ -419,12 +424,14 @@ ggbar <- function(df, xvar, f_axis, color_bg, sep_mark, coord_flip){
 
 
 #' @keywords internal
-ggcoordflip <- function(coord_flip){
-  if ( isTRUE(coord_flip) ) {
+ggcoordflip <- function(coord_flip) {
+  if (isTRUE(coord_flip)) {
     list(
       ggplot2::coord_flip()
     )
-  } else { NULL }
+  } else {
+    NULL
+  }
 }
 
 
@@ -454,7 +461,7 @@ overlap_right <- function(positions, cut_off) {
 
   positions <- positions[!is.na(positions)]
   n <- length(positions)
-  ticks_dif <- positions[n] - positions[n-1]
+  ticks_dif <- positions[n] - positions[n - 1]
   (cut_off - positions[n]) / ticks_dif < 0.25
 }
 
@@ -490,29 +497,34 @@ overlap_left <- function(positions, cut_off) {
 #' @importFrom ggplot2 autoplot
 #' @import data.table
 #' @keywords internal
-split_x_fn <- function(data, x, left = NULL, right = NULL){
+split_x_fn <- function(data, x, left = NULL, right = NULL) {
 
   vec <- data[[x]]
   vec_new <- data.table::data.table(data)[get(x) > right, c(x) := right][
-    get(x) < left, c(x) := left][,get(x)]
+    get(x) < left, c(x) := left][, get(x)]
 
-  if ( !is.null(left) ){
-    if ( left <= min(vec, na.rm = TRUE)){
-      stop( "Left should be greater than minimum value", call. = FALSE ) }
-    if ( left >= max(vec, na.rm = TRUE)){
-      stop( "Left should be less than maximum value", call. = FALSE )}
+  if (!is.null(left)) {
+    if (left <= min(vec, na.rm = TRUE)) {
+      stop("Left should be greater than minimum value", call. = FALSE)
+    }
+    if (left >= max(vec, na.rm = TRUE)) {
+      stop("Left should be less than maximum value", call. = FALSE)
+    }
   }
 
-  if ( !is.null(right) ){
-    if ( right >= max(vec, na.rm = TRUE)){
-      stop( "Right should be less than maximum value", call. = FALSE ) }
-    if ( right <= min(vec, na.rm = TRUE)){
-      stop( "Right should be greater than minimum value", call. = FALSE)}
+  if (!is.null(right)) {
+    if (right >= max(vec, na.rm = TRUE)) {
+      stop("Right should be less than maximum value", call. = FALSE)
+    }
+    if (right <= min(vec, na.rm = TRUE)) {
+      stop("Right should be greater than minimum value", call. = FALSE)
+    }
   }
 
-  if ( !is.null(left) & !is.null(right)){
-    if ( left >= right ){
-      stop( "Right should be larger than left", call. = FALSE) }
+  if (!is.null(left) && !is.null(right)) {
+    if (left >= right) {
+      stop("Right should be larger than left", call. = FALSE)
+    }
   }
 
   l1 <- split(vec_new, cut(vec_new,
@@ -521,40 +533,40 @@ split_x_fn <- function(data, x, left = NULL, right = NULL){
                            include.lowest = TRUE))
 
   l1 <- lapply(l1, function(x) data.frame(x = x))
-  if ( is.null(left) ){ l1 <- append(list(NULL), l1) }
-  if ( is.null(right) ){ l1 <- append(l1, list(NULL)) }
-  return(l1)
+  if (is.null(left)) l1 <- append(list(NULL), l1)
+  if (is.null(right)) l1 <- append(l1, list(NULL))
+  l1
 }
 
 #' @keywords internal
-construct_fm <- function(lhs, rhs){
+construct_fm <- function(lhs, rhs) {
   as.formula(paste0(paste0(lhs, collapse = " + "), "~ ", rhs))
 }
 
 
 #' @keywords internal
-moments <- function(x, dist = c("gamma", "lognormal")){
+moments <- function(x, dist = c("gamma", "lognormal")) {
 
   dist <- match.arg(dist)
   m <- mean(x, na.rm = TRUE)
   s <- sd(x, na.rm = TRUE)
   v <- s^2
 
-  if ( dist == "gamma" ){
+  if (dist == "gamma") {
     scale <- m ^ 2 / s
     shape <- s / m
     return(list(scale = scale, shape = shape))
   }
 
-  if ( dist == "lognormal" ){
-    meanlog <- log(m ^ 2 / sqrt(v + m ^ 2) )
-    sdlog <- log( v / (m ^ 2) + 1)
+  if (dist == "lognormal") {
+    meanlog <- log(m ^ 2 / sqrt(v + m ^ 2))
+    sdlog <- log(v / (m ^ 2) + 1)
     return(list(meanlog = meanlog, sdlog = sdlog))
   }
 }
 
 #' @keywords internal
-dtrunc <- function( x, spec, a = -Inf, b= Inf, ... ){
+dtrunc <- function(x, spec, a = -Inf, b = Inf, ...) {
   ###
   ### this function computes the density function defined by the spec argument
   ### for the vector of quantile values in x.  The random variable is truncated
@@ -565,47 +577,68 @@ dtrunc <- function( x, spec, a = -Inf, b= Inf, ... ){
   ### spec = a character value for the name of the distribution (e.g., "norm")
   ### ... = other arguments passed to the corresponding density function
   ###
-  if ( a >= b )
-    stop( "argument a is greater than or equal to b" )
-  tt <- rep( 0, length( x ) )
-  g <- get( paste( "d", spec, sep="" ), mode="function" )
-  G <- get( paste( "p", spec, sep="" ), mode="function" )
-  G.a <- G( a, ... )
-  G.b <- G( b, ... )
-  if ( G.a == G.b ) {
-    stop( "Trunction interval is not inside the domain of the density function" )
+  if (a >= b)
+    stop("argument a is greater than or equal to b")
+  tt <- rep(0, length(x))
+  g <- get(paste("d", spec, sep = ""), mode = "function")
+  G <- get(paste("p", spec, sep = ""), mode = "function")
+  G.a <- G(a, ...)
+  G.b <- G(b, ...)
+  if (G.a == G.b) {
+    stop("Trunction interval is not inside the domain of the density function")
   }
-  tt[x >= a & x <= b] <- g( x[x >= a & x <= b], ...) / ( G( b, ... ) - G( a, ... ) )
-  return( tt )
+  tt[x >= a & x <= b] <- g(x[x >= a & x <= b], ...) / (G(b, ...) - G(a, ...))
+  tt
 }
 
 #' @keywords internal
-ptrunc <- function( q, spec, a = -Inf, b = Inf, ... )
-{
+ptrunc <- function(q, spec, a = -Inf, b = Inf, ...) {
   ###
-  ### this function computes the distribution function defined by the spec argument
-  ### for the vector of quantile values in x.  The random variable is truncated
-  ### to be in the interval ( a, b )
+  ### this function computes the distribution function defined by the spec
+  ### argument for the vector of quantile values in x.  The random variable is
+  ### truncated to be in the interval ( a, b )
   ###
   ### Arguments
   ### q = a numeric vector of quantiles
   ### spec = a character value for the name of the distribution (e.g., "norm")
   ### ... = other arguments passed to the corresponding density function
   ###
-  if ( a >= b )
-    stop( "argument a is greater than or equal to b" )
+  if (a >= b)
+    stop("argument a is greater than or equal to b")
   tt <- q
-  aa <- rep( a, length( q ) )
-  bb <- rep( b, length( q ) )
-  G <- get( paste( "p", spec, sep="" ), mode="function" )
-  tt <- G( apply( cbind( apply( cbind( q, bb ), 1, min ), aa ), 1, max ), ... )
-  tt <- tt - G ( aa, ... )
-  G.a <- G( aa, ... )
-  G.b <- G( bb, ... )
-  if ( any( G.a == G.b ) ) {
-    stop( "Trunction interval is not inside the domain of the distribution function" )
+  aa <- rep(a, length(q))
+  bb <- rep(b, length(q))
+  G <- get(paste("p", spec, sep = ""), mode = "function")
+  tt <- G(apply(cbind(apply(cbind(q, bb), 1, min), aa), 1, max), ...)
+  tt <- tt - G(aa, ...)
+  G.a <- G(aa, ...)
+  G.b <- G(bb, ...)
+  if (any(G.a == G.b)) {
+    stop(
+      "Trunction interval is not inside the domain of the distribution function"
+    )
   }
-  result <- tt / ( G( bb, ... ) - G ( aa, ... ) )
-  return( result )
+  tt / (G(bb, ...) - G(aa, ...))
 }
 
+#' @keywords internal
+color_blue <- function(x) {
+  x[!is.na(x)] <- paste0("\033[", "3", "4m", x[!is.na(x)],
+                         "\033[", "3", "9m")
+  x
+}
+
+
+#' @keywords internal
+color_red <- function(x) {
+  x[!is.na(x)] <- paste0("\033[", "3", "1m", x[!is.na(x)],
+                         "\033[", "3", "9m")
+  x
+}
+
+#' @keywords internal
+color_green <- function(x) {
+  x[!is.na(x)] <- paste0("\033[", "3", "2m", x[!is.na(x)],
+                         "\033[", "3", "9m")
+  x
+}
